@@ -1,7 +1,8 @@
-DearBeggToMinimize <- function(vec, y, u, lam, teststat){
+DearBeggToMinimize <- function(vec, y, u, lam){
     n <- length(y)
     k <- 1 + floor(n / 2)
     w <- vec[1:k]
+    teststat <- abs(y) / u
 
     res <- Inf
     crit1 <- min(diff(w)) >= 0
